@@ -68,14 +68,6 @@ class STManager(BulkManager):
     tbl_name = "buckeyebrowser_segmenttoken"
     cols = ['id','WordToken_id','SegmentType_id','Begin','End']
 
-class PCManager(BulkManager):
-    tbl_name = 'buckeyebrowser_prevcondprobs'
-    cols = ['id','ActWord_id','PreviousWord_id','Count','Prob']
-
-class FCManager(BulkManager):
-    tbl_name = 'buckeyebrowser_follcondprobs'
-    cols = ['id','ActWord_id','FollowingWord_id','Count','Prob']
-
 class Speaker(models.Model):
     Number = models.CharField(max_length=3)
     Gender = models.CharField(max_length=10)
@@ -135,7 +127,7 @@ Group by StressVowel) AS averages""",[self.pk])
         Dialog.objects.bulk_create([ Dialog(Speaker=self,Number=d) for d in dialogs])
 
     def analyze(self,form):
-        words = WordToken.objects.filter(Dialog__Speaker=self)
+        words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker').filter(Dialog__Speaker=self)
         words = words.filter(WordType__CVSkel='CVC')
         words = words.filter(WordType__Label__in = GOOD_WORDS).order_by('Dialog')
         allout = []
@@ -292,8 +284,6 @@ class PrevCondProbs(models.Model):
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
-    objects = PCManager()
-
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
@@ -312,8 +302,6 @@ class FollCondProbs(models.Model):
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
-    objects = FCManager()
-
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
