@@ -84,14 +84,14 @@ def combineResults(allout):
 
 @task()
 def AnalyzeSpeaker(speaker,form):
-    #return speaker.analyze(form)
-    out = speaker.analyze(form)
-    with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
-        f.write("\t".join(out[0].keys()))
-        f.write("\n")
-        for l in out:
-            f.write("\t".join(map(str,l.values())))
-            f.write("\n")
+    return speaker.analyze(form)
+    #out = speaker.analyze(form)
+    #with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
+    #    f.write("\t".join(out[0].keys()))
+    #    f.write("\n")
+    #    for l in out:
+    #        f.write("\t".join(map(str,l.values())))
+    #        f.write("\n")
 
 @task()
 def doBasicAnalysis(form):
@@ -100,10 +100,10 @@ def doBasicAnalysis(form):
         sp = Speaker.objects.filter(Number = 's03')
         out = AnalyzeSpeaker.delay(sp[0],form)
     else:
-        for s in sp:
-            AnalyzeSpeaker.delay(s,form)
-        #res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s())()
-        #res.get()
+        #for s in sp:
+        #    AnalyzeSpeaker.delay(s,form)
+        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s())()
+        res.get()
 
 #@
 #def consolidateResultFiles():
